@@ -187,10 +187,7 @@ def rnpfind(
     data_load_sources = (
         sources if sources else data_load_sources_supported_short
     )
-    # print(
-    #     f"Collecting data from: {', '.join(data_load_sources)}",
-    #     file=sys.stderr,
-    # )
+
     # load RNA-RBP interaction data using the selected data sources on the RNA
     # molecule of interest big_storage stores data on binding sites of RBPs on
     # the RNA molecule from each data source. For more details on how
@@ -207,25 +204,27 @@ def rnpfind(
     # Give a quick summary on the data that has been loaded, in terms of total
     # number of RBPs and binding sites collected for the RNA molecule of
     # interest
-    no_rbps = 0
     no_sites = 0
-    for no_rbp, no_site in [big_storage[k].summary() for k in big_storage]:
-        no_rbps += no_rbp
+    uniq_rbps = set()
+    for data_source, storage in big_storage.items():
+        no_rbp, no_site = storage.summary()
+        print(
+            f"Collected data for {no_rbp} RBPs with {no_site}"
+            f" binding sites (from {data_source})",
+            file=sys.stderr,
+        )
         no_sites += no_site
+        uniq_rbps.update(storage.get_rbps())
 
     print(
-        f"Collected data for {no_rbps} RBPs with {no_sites} binding sites",
+        f"Collected data for {len(uniq_rbps)} unique RBPs with {no_sites}"
+        " binding sites (total)",
         file=sys.stderr,
     )
 
     # We now proceed to perform any number of analysis methods that the user
     # may wish to apply to the data obtained
     analysis_methods = methods if methods else analysis_methods_supported_short
-    # print(
-    #     "Producing the following output formats:"
-    #     f" {', '.join(analysis_methods)}",
-    #     file=sys.stderr,
-    # )
 
     if out_dir:
         # The user specified an out directory
